@@ -10,6 +10,8 @@
 
 #pragma once
 
+#include <ostream>
+
 //------------------------------------------------------------------------------
 
 namespace atlas {
@@ -75,6 +77,10 @@ public:
     int end(const View& view, int i) const {
         return view.shape(i);
     }
+    friend std::ostream& operator<<(std::ostream& out, const RangeAll& range) {
+        out << ":";
+        return out;
+    }
 };
 
 class RangeDummy : public RangeBase {};
