@@ -13,4 +13,7 @@ CubedSphereGrid2::CubedSphereGrid2(idx_t resolution):
 CubedSphereGrid2::CubedSphereGrid2(const Grid& grid):
     Grid(grid), grid_(cubedsphere_grid2(get())) {}
 
+CubedSphereGrid2::CubedSphereGrid2(idx_t resolution, Projection projection):
+    Grid(new grid::detail::grid::CubedSphere2(resolution, projection)), grid_(cubedsphere_grid2(get())) {}
+
 }  // namespace atlas
