@@ -21,16 +21,21 @@ namespace grid {
 namespace detail {
 namespace distribution {
 
-SerialDistribution::SerialDistribution(const Grid& grid): DistributionFunctionT<SerialDistribution>(grid) {
+SerialDistribution::SerialDistribution(const Grid& grid):
+    SerialDistribution(grid, mpi::rank()) {
+}
+
+SerialDistribution::SerialDistribution(const Grid& grid, int part): DistributionFunctionT<SerialDistribution>(grid) {
     type_          = "serial";
     nb_partitions_ = 1;
-    rank_          = mpi::rank();
     size_          = grid.size();
     nb_pts_.resize(nb_partitions_, grid.size());
     max_pts_ = *std::max_element(nb_pts_.begin(), nb_pts_.end());
     min_pts_ = *std::min_element(nb_pts_.begin(), nb_pts_.end());
+    part_          = part;
 }
 
+
 }  // namespace distribution
 }  // namespace detail
 }  // namespace grid
