@@ -10,6 +10,8 @@
 
 #include "atlas/grid/detail/partitioner/MatchingFunctionSpacePartitioner.h"
 
+#include <sstream>
+
 #include "atlas/functionspace/FunctionSpace.h"
 #include "atlas/runtime/Exception.h"
 
@@ -19,16 +21,16 @@ namespace detail {
 namespace partitioner {
 
 MatchingFunctionSpacePartitioner::MatchingFunctionSpacePartitioner(): Partitioner() {
-    ATLAS_NOTIMPLEMENTED;
+    ATLAS_THROW_EXCEPTION("Error: A MatchingFunctionPartitioner needs to be initialised with a FunctionSpace");
 }
 
-MatchingFunctionSpacePartitioner::MatchingFunctionSpacePartitioner(const idx_t nb_partitions):
-    Partitioner(nb_partitions) {
-    ATLAS_NOTIMPLEMENTED;
-}
+// MatchingFunctionSpacePartitioner::MatchingFunctionSpacePartitioner(const idx_t nb_partitions):
+//     Partitioner(nb_partitions) {
+//     ATLAS_NOTIMPLEMENTED;
+// }
 
-MatchingFunctionSpacePartitioner::MatchingFunctionSpacePartitioner(const FunctionSpace& functionspace):
-    Partitioner(functionspace.nb_partitions()), partitioned_(functionspace) {}
+MatchingFunctionSpacePartitioner::MatchingFunctionSpacePartitioner(const FunctionSpace& functionspace, const eckit::Parametrisation&):
+    Partitioner(functionspace.nb_parts(),util::Config("mpi_comm",functionspace.mpi_comm())), partitioned_(functionspace) {}
 
 }  // namespace partitioner
 }  // namespace detail
