@@ -285,6 +285,57 @@ public:
         }
     }
 
+
+    template <typename stencil_t, typename weights_t, typename Value, int Rank>
+    typename std::enable_if<(Rank == 3), void>::type interpolate(const stencil_t& stencil, const weights_t& weights,
+                                                                 const array::ArrayView<const Value, Rank>& input,
+                                                                 array::ArrayView<Value, Rank>& output, idx_t r) const {
+        std::array<std::array<idx_t, stencil_width()>, stencil_width()> index;
+        const auto& weights_j = weights.weights_j;
+        const idx_t Nk        = output.shape(1);
+        const idx_t Nl        = output.shape(2);
+        for (idx_t k = 0; k < Nk; ++k) {
+            for (idx_t l = 0; l < Nl; ++l) {
+                output(r, k, l) = 0.;
+            }
+        }
+
+        // LINEAR for outer rows  ( j = {0,3} )
+        for (idx_t j = 0; j < 4; j += 3) {
+            const auto& weights_i = weights.weights_i[j];
+            for (idx_t i = 1; i < 3; ++i) {  // i = {1,2}
+                idx_t n = src_.index(stencil.i(i, j), stencil.j(j));
+                Value w = weights_i[i] * weights_j[j];
+                for (idx_t k = 0; k < Nk; ++k) {
+                    for (idx_t l = 0; l < Nl; ++l) {
+                        output(r, k, l) += w * input(n, k, l);
+                    }
+                }
+                index[j][i] = n;
+            }
+        }
+        // CUBIC for inner rows ( j = {1,2} )
+        for (idx_t j = 1; j < 3; ++j) {
+            const auto& weights_i = weights.weights_i[j];
+            for (idx_t i = 0; i < stencil_width(); ++i) {
+                idx_t n = src_.index(stencil.i(i, j), stencil.j(j));
+                Value w = weights_i[i] * weights_j[j];
+                for (idx_t k = 0; k < Nk; ++k) {
+                    for (idx_t l = 0; l < Nl; ++l) {
+                        output(r, k, l) += w * input(n, k, l);
+                    }
+                }
+                index[j][i] = n;
+            }
+        }
+
+        if (limiter_) {
+            Limiter::limit(index, input, output, r);
+        }
+    }
+
+
+
     template <typename array_t>
     typename array_t::value_type operator()(double x, double y, const array_t& input) const {
         Stencil stencil;
