@@ -23,11 +23,15 @@
 #include "eckit/log/OStreamTarget.h"
 #include "eckit/log/PrefixTarget.h"
 #include "eckit/runtime/Main.h"
+
+#include "pluto/pluto.h"
+
 #include "eckit/system/SystemInfo.h"
 #include "eckit/types/Types.h"
 #include "eckit/utils/Translator.h"
 #include "eckit/system/LibraryManager.h"
 
+
 #if ATLAS_ECKIT_HAVE_ECKIT_585
 #include "eckit/linalg/LinearAlgebraDense.h"
 namespace {
@@ -44,6 +48,8 @@ static bool feature_MKL() {
 }  // namespace
 #endif
 
+#include "pluto/pluto.h"
+
 #include "atlas_io/Trace.h"
 
 #include "atlas/library/FloatingPointExceptions.h"
@@ -53,6 +59,7 @@ static bool feature_MKL() {
 #include "atlas/library/version.h"
 #include "atlas/parallel/mpi/mpi.h"
 #include "atlas/parallel/omp/omp.h"
+#include "atlas/parallel/acc/acc.h"
 #include "atlas/runtime/Exception.h"
 #include "atlas/runtime/Log.h"
 #include "atlas/runtime/Trace.h"
@@ -341,6 +348,9 @@ void Library::initialise(const eckit::Parametrisation& config) {
         out << "    rank          [" << mpi::rank() << "] \n";
         out << "  OMP\n";
         out << "    max_threads   [" << atlas_omp_get_max_threads() << "] \n";
+        out << "  GPU\n";
+        out << "    devices       [" << pluto::devices() << "] \n";
+        out << "    OpenACC       [" << acc::devices() << "] \n";
         out << " \n";
         out << "  log.info        [" << str(info_) << "] \n";
         out << "  log.trace       [" << str(trace()) << "] \n";
@@ -352,6 +362,8 @@ void Library::initialise(const eckit::Parametrisation& config) {
         out << atlas::Library::instance().information();
         out << std::flush;
     }
+
+    pluto::trace::set(eckit::Log::info());
 }
 
 
@@ -367,6 +379,7 @@ void Library::finalise() {
 
     if (ATLAS_HAVE_TRACE && trace_report_) {
         Log::info() << atlas::Trace::report() << std::endl;
+        Log::info() << pluto::memory::report() << std::endl;
     }
 
     if (getEnv("ATLAS_FINALISES_MPI", false)) {
@@ -379,6 +392,12 @@ void Library::finalise() {
     // Just in case someone still tries to log, we reset to empty channels.
     trace_channel_.reset(new eckit::Channel());
 
+    if (pluto::trace::enabled()) {
+        Log::debug() << "Disabling pluto::trace during atlas::Library::finalise()" << std::endl;
+        pluto::trace::out << "PLUTO_TRACE pluto::trace::enable(false)" << std::endl;
+    }
+    pluto::trace::enable(false);
+
     Log::debug() << "Atlas finalised" << std::endl;
 
     Log::flush();
@@ -473,6 +492,8 @@ void Library::Information::print(std::ostream& out) const {
 
     bool feature_fortran(ATLAS_HAVE_FORTRAN);
     bool feature_OpenMP(ATLAS_HAVE_OMP);
+    bool feature_OpenACC(ATLAS_HAVE_ACC);
+    bool feature_GPU(ATLAS_HAVE_GPU);
     bool feature_ecTrans(ATLAS_HAVE_ECTRANS);
     bool feature_FFTW(ATLAS_HAVE_FFTW);
     bool feature_Eigen(ATLAS_HAVE_EIGEN);
@@ -498,6 +519,8 @@ void Library::Information::print(std::ostream& out) const {
         << "    Fortran        : " << str(feature_fortran) << '\n'
         << "    MPI            : " << str(feature_MPI) << '\n'
         << "    OpenMP         : " << str(feature_OpenMP) << '\n'
+        << "    OpenACC        : " << str(feature_OpenACC) << '\n'
+        << "    GPU            : " << str(feature_GPU) << '\n'
         << "    BoundsChecking : " << str(feature_BoundsChecking) << '\n'
         << "    Init_sNaN      : " << str(feature_Init_sNaN) << '\n'
         << "    ecTrans        : " << str(feature_ecTrans) << '\n'
