@@ -396,7 +396,7 @@ We need to connect to next region
 
     region.elems.reset(array::Array::create<int>(shape));
 
-    int nelems     = 0;
+    [[maybe_unused]] int nelems     = 0;
     region.nquads  = 0;
     region.ntriags = 0;
 
@@ -1338,10 +1338,6 @@ void StructuredMeshGenerator::generate_mesh(const StructuredGrid& rg, const grid
                 cells_glb_idx(jcell) = jcell + 1;
                 cells_part(jcell)    = mypart;
                 if( regular_cells_glb_idx ) {
-                    gidx_t nx = rg.nx(jlatN) - 1;
-                    if (periodic_east_west) {
-                        ++nx;
-                    }
                     cells_glb_idx(jcell) = glb_idx( quad_nodes[0] );
                 }
             }
