@@ -21,89 +21,89 @@
 #include "atlas/runtime/AtlasTool.h"
 
 namespace atlas {
-static void usage( const std::string& name ) {
+static void usage(const std::string& name) {
     Log::info() << "dummy usage" << std::endl;
 }
 }  // namespace atlas
 
 namespace {
 
-int digits( int number ) {
+int digits(int number) {
     int d = 0;
-    while ( number ) {
+    while (number) {
         number /= 10;
         d++;
     }
     return d;
 }
 
-static std::string debug_prefix( const std::string& libname ) {
+static std::string debug_prefix(const std::string& libname) {
     std::string s = libname;
-    std::transform( s.begin(), s.end(), s.begin(), ::toupper );
+    std::transform(s.begin(), s.end(), s.begin(), ::toupper);
     s += "_DEBUG";
     return s;
 }
 
-void debug_addTarget( eckit::LogTarget* target ) {
-    for ( std::string libname : eckit::system::Library::list() ) {
-        const eckit::system::Library& lib = eckit::system::Library::lookup( libname );
-        if ( lib.debug() ) {
-            lib.debugChannel().addTarget( new eckit::PrefixTarget( debug_prefix( libname ), target ) );
+void debug_addTarget(eckit::LogTarget* target) {
+    for (std::string libname : eckit::system::Library::list()) {
+        const eckit::system::Library& lib = eckit::system::Library::lookup(libname);
+        if (lib.debug()) {
+            lib.debugChannel().addTarget(new eckit::PrefixTarget(debug_prefix(libname), target));
         }
     }
-    if ( eckit::Log::debug() ) {
-        eckit::Log::debug().addTarget( target );
+    if (eckit::Log::debug()) {
+        eckit::Log::debug().addTarget(target);
     }
 }
 
-void debug_setTarget( eckit::LogTarget* target ) {
-    for ( std::string libname : eckit::system::Library::list() ) {
-        const eckit::system::Library& lib = eckit::system::Library::lookup( libname );
-        if ( lib.debug() ) {
-            lib.debugChannel().setTarget( new eckit::PrefixTarget( debug_prefix( libname ), target ) );
+void debug_setTarget(eckit::LogTarget* target) {
+    for (std::string libname : eckit::system::Library::list()) {
+        const eckit::system::Library& lib = eckit::system::Library::lookup(libname);
+        if (lib.debug()) {
+            lib.debugChannel().setTarget(new eckit::PrefixTarget(debug_prefix(libname), target));
         }
     }
-    if ( eckit::Log::debug() ) {
-        eckit::Log::debug().setTarget( target );
+    if (eckit::Log::debug()) {
+        eckit::Log::debug().setTarget(target);
     }
 }
 
 void debug_reset() {
-    for ( std::string libname : eckit::system::Library::list() ) {
-        const eckit::system::Library& lib = eckit::system::Library::lookup( libname );
-        if ( lib.debug() ) {
+    for (std::string libname : eckit::system::Library::list()) {
+        const eckit::system::Library& lib = eckit::system::Library::lookup(libname);
+        if (lib.debug()) {
             lib.debugChannel().reset();
         }
     }
-    if ( eckit::Log::debug() ) {
+    if (eckit::Log::debug()) {
         eckit::Log::debug().reset();
     }
 }
 
-bool getEnv( const std::string& env, bool default_value ) {
-    if ( ::getenv( env.c_str() ) ) {
-        return eckit::Translator<std::string, bool>()( ::getenv( env.c_str() ) );
+bool getEnv(const std::string& env, bool default_value) {
+    if (::getenv(env.c_str())) {
+        return eckit::Translator<std::string, bool>()(::getenv(env.c_str()));
     }
     return default_value;
 }
 
-int getEnv( const std::string& env, int default_value ) {
-    if ( ::getenv( env.c_str() ) ) {
-        return eckit::Translator<std::string, int>()( ::getenv( env.c_str() ) );
+int getEnv(const std::string& env, int default_value) {
+    if (::getenv(env.c_str())) {
+        return eckit::Translator<std::string, int>()(::getenv(env.c_str()));
     }
     return default_value;
 }
 
-std::string getEnv( const std::string& env, const std::string& default_value ) {
-    if ( ::getenv( env.c_str() ) ) {
-        return ::getenv( env.c_str() );
+std::string getEnv(const std::string& env, const std::string& default_value) {
+    if (::getenv(env.c_str())) {
+        return ::getenv(env.c_str());
     }
     return default_value;
 }
 
-void setEnv( const std::string& env, bool value ) {
+void setEnv(const std::string& env, bool value) {
     constexpr int DO_NOT_REPLACE_IF_EXISTS = 0;
-    ::setenv( env.c_str(), eckit::Translator<bool, std::string>()( value ).c_str(), DO_NOT_REPLACE_IF_EXISTS );
+    ::setenv(env.c_str(), eckit::Translator<bool, std::string>()(value).c_str(), DO_NOT_REPLACE_IF_EXISTS);
 }
 
 
@@ -121,22 +121,22 @@ static std::string workdir;
 
     Log::flush();
 
-    if ( not use_logfile and mpi::size() > 1 ) {
-        eckit::LogTarget* logfile = new eckit::FileTarget( logfile_name );
-        Log::error().addTarget( logfile );
+    if (not use_logfile and mpi::size() > 1) {
+        eckit::LogTarget* logfile = new eckit::FileTarget(logfile_name);
+        Log::error().addTarget(logfile);
     }
-    if ( std::exception_ptr eptr = std::current_exception() ) {
+    if (std::exception_ptr eptr = std::current_exception()) {
         std::ostream& out = Log::error();
         try {
-            std::rethrow_exception( eptr );  // throw to recognise the type
+            std::rethrow_exception(eptr);  // throw to recognise the type
         }
-        catch ( const eckit::Abort& exception ) {
+        catch (const eckit::Abort& exception) {
             out << "\n"
                 << "=========================================\n"
                 << "[" << mpi::rank() << "] Aborting " << eckit::Main::instance().displayName() << "\n"
                 << "-----------------------------------------\n"
                 << exception.what() << "\n";
-            if ( exception.location() ) {
+            if (exception.location()) {
                 out << "-----------------------------------------\n"
                     << "LOCATION: " << exception.location() << "\n";
             }
@@ -147,7 +147,7 @@ static std::string workdir;
                 << "=========================================\n"
                 << std::endl;
         }
-        catch ( const eckit::Exception& exception ) {
+        catch (const eckit::Exception& exception) {
             out << "\n"
                 << "=========================================\n"
                 << "[" << mpi::rank() << "] TERMINATING " << eckit::Main::instance().displayName() << "\n"
@@ -155,7 +155,7 @@ static std::string workdir;
                 << exception.what() << "\n"
                 << "-----------------------------------------\n";
 
-            if ( exception.location() ) {
+            if (exception.location()) {
                 out << "LOCATION: " << exception.location() << "\n"
                     << "-----------------------------------------\n";
             }
@@ -166,7 +166,7 @@ static std::string workdir;
                 << "=========================================\n"
                 << std::endl;
         }
-        catch ( const std::exception& exception ) {
+        catch (const std::exception& exception) {
             out << "\n"
                 << "=========================================\n"
                 << "[" << mpi::rank() << "] TERMINATING " << eckit::Main::instance().displayName() << "\n"
@@ -179,7 +179,7 @@ static std::string workdir;
                 << "=========================================\n"
                 << std::endl;
         }
-        catch ( ... ) {
+        catch (...) {
             out << "\n"
                 << "=========================================\n"
                 << "[" << mpi::rank() << "] TERMINATING " << eckit::Main::instance().displayName() << "\n"
@@ -195,46 +195,59 @@ static std::string workdir;
 
     // Just in case we end up here, as last resort, exit immediately without
     // cleanup.
-    std::_Exit( EXIT_FAILURE );
+    std::_Exit(EXIT_FAILURE);
 }
 
 }  // namespace atlas
 
 
-void atlas::AtlasTool::add_option( eckit::option::Option* option ) {
-    options_.push_back( option );
+void atlas::AtlasTool::add_option(eckit::option::Option* option) {
+    options_.push_back(option);
 }
 
-void atlas::AtlasTool::help( std::ostream& out ) {
-    out << "NAME\n" << indent() << name();
+void atlas::AtlasTool::help(std::ostream& out) {
+    auto indented = [&](const std::string& s) -> std::string {
+        std::string str = indent() + s;
+        size_t pos      = 0;
+        while ((pos = str.find('\n', pos)) != std::string::npos) {
+            str.replace(pos, 1, '\n' + indent());
+            ++pos;
+        }
+        return str;
+    };
+
+
+    out << "NAME\n" << indented(name());
     std::string brief = briefDescription();
-    if ( brief.size() ) {
+    if (brief.size()) {
         out << " - " << brief << '\n';
     }
 
     std::string usg = usage();
-    if ( usg.size() ) {
+    if (usg.size()) {
         out << '\n';
-        out << "SYNOPSIS\n" << indent() << usg << '\n';
+        out << "SYNOPSIS\n" << indented(usg) << '\n';
     }
     std::string desc = longDescription();
-    if ( desc.size() ) {
+    if (desc.size()) {
         out << '\n';
-        out << "DESCRIPTION\n" << indent() << desc << '\n';
+        out << "DESCRIPTION\n" << indented(desc) << '\n';
     }
     out << '\n';
     out << "OPTIONS\n";
-    for ( Options::const_iterator it = options_.begin(); it != options_.end(); ++it ) {
-        out << indent() << ( **it ) << "\n\n";
+    for (Options::const_iterator it = options_.begin(); it != options_.end(); ++it) {
+        std::stringstream s;
+        s << **it;
+        out << indented(s.str()) << "\n\n";
     }
     out << std::flush;
 }
 
 bool atlas::AtlasTool::handle_help() {
-    for ( int i = 1; i < argc(); ++i ) {
-        if ( argv( i ) == "--help" || argv( i ) == "-h" ) {
-            if ( taskID() == 0 ) {
-                help( std::cout );
+    for (int i = 1; i < argc(); ++i) {
+        if (argv(i) == "--help" || argv(i) == "-h") {
+            if (taskID() == 0) {
+                help(std::cout);
             }
             return true;
         }
@@ -242,38 +255,54 @@ bool atlas::AtlasTool::handle_help() {
     return false;
 }
 
-atlas::AtlasTool::AtlasTool( int argc, char** argv ) : eckit::Tool( argc, argv ) {
-    eckit::LibEcKit::instance().setAbortHandler( [] {
+std::string atlas::AtlasTool::get_positional_arg(const Args& args, size_t p) const {
+    int c = 0;
+    for (int i = 0; i < args.count(); ++i) {
+        if (args(i)[0] == '-') {
+            i++;
+        }
+        else {
+            if (c == p) {
+                return args(i);
+            }
+            c++;
+        }
+    }
+    return std::string{};
+}
+
+atlas::AtlasTool::AtlasTool(int argc, char** argv): eckit::Tool(argc, argv) {
+    eckit::LibEcKit::instance().setAbortHandler([] {
         std::cerr << "[" << atlas::mpi::rank() << "] "
                   << "calling MPI_Abort";
-        if ( not use_logfile and mpi::size() > 1 ) {
+        if (not use_logfile and mpi::size() > 1) {
             std::cerr << ", logfile: " << logfile_name;
         }
         std::cerr << std::endl;
-        std::this_thread::sleep_for( std::chrono::milliseconds( 3000 ) );
-        atlas::mpi::comm().abort( 1 );
-    } );
-    std::set_terminate( &atlas_terminate );
-    setEnv( "ECKIT_EXCEPTION_IS_SILENT", true );
-    setEnv( "ECKIT_ASSERT_FAILED_IS_SILENT", true );
-    setEnv( "ATLAS_FPE", true );
-    setEnv( "ATLAS_SIGNAL_HANDLER", true );
-    add_option( new SimpleOption<bool>( "help", "Print this help" ) );
-    add_option( new SimpleOption<long>( "debug", "Debug level" ) );
-    taskID( eckit::mpi::comm( "world" ).rank() );
-    workdir = getEnv( "ATLAS_WORKDIR", eckit::PathName( eckit::LocalPathName::cwd() ).fullName() );
+        std::this_thread::sleep_for(std::chrono::milliseconds(3000));
+        atlas::mpi::comm().abort(1);
+    });
+    std::set_terminate(&atlas_terminate);
+    setEnv("ECKIT_EXCEPTION_IS_SILENT", true);
+    setEnv("ECKIT_ASSERT_FAILED_IS_SILENT", true);
+    setEnv("ATLAS_FPE", true);
+    setEnv("ATLAS_SIGNAL_HANDLER", true);
+    add_option(new SimpleOption<bool>("help", "Print this help"));
+    add_option(new SimpleOption<long>("debug", "Debug level"));
+    taskID(eckit::mpi::comm("world").rank());
+    workdir = getEnv("ATLAS_WORKDIR", eckit::PathName(eckit::LocalPathName::cwd()).fullName());
 
-    add_option( new SimpleOption<std::string>( "display-name", "Name to give to program" ) );
+    add_option(new SimpleOption<std::string>("display-name", "Name to give to program"));
 }
 
 int atlas::AtlasTool::start() {
     try {
-        if ( handle_help() ) {
+        if (handle_help()) {
             return success();
         }
 
-        if ( argc() - 1 < minimumPositionalArguments() ) {
-            if ( taskID() == 0 ) {
+        if (argc() - 1 < minimumPositionalArguments()) {
+            if (taskID() == 0) {
                 std::cout << "Usage: " << usage() << std::endl;
             }
             return failed();
@@ -282,14 +311,14 @@ int atlas::AtlasTool::start() {
         setupLogging();
 
         Options opts = options_;
-        Args args( &atlas::usage, opts, numberOfPositionalArguments(), minimumPositionalArguments() > 0 );
+        Args args(&atlas::usage, opts, numberOfPositionalArguments(), minimumPositionalArguments() > 0);
 
-        int err_code = execute( args );
+        int err_code = execute(args);
         atlas::finalize();
         atlas::mpi::finalize();
         return err_code;
     }
-    catch ( ... ) {
+    catch (...) {
         atlas_terminate();
     }
 }
@@ -297,54 +326,54 @@ int atlas::AtlasTool::start() {
 void atlas::AtlasTool::run() {}
 
 void atlas::AtlasTool::setupLogging() {
-    int log_rank = getEnv( "ATLAS_LOG_RANK", 0 );
-    use_logfile  = getEnv( "ATLAS_LOG_FILE", false );
+    int log_rank = getEnv("ATLAS_LOG_RANK", 0);
+    use_logfile  = getEnv("ATLAS_LOG_FILE", false);
 
-    int d               = digits( mpi::size() );
-    std::string rankstr = std::to_string( taskID() );
-    for ( int i = rankstr.size(); i < d; ++i ) {
+    int d               = digits(mpi::size());
+    std::string rankstr = std::to_string(taskID());
+    for (int i = rankstr.size(); i < d; ++i) {
         rankstr = "0" + rankstr;
     }
 
     logfile_name = workdir + "/" + displayName() + ".log.p" + rankstr;
 
-    if ( use_logfile ) {
-        eckit::LogTarget* logfile = new eckit::FileTarget( logfile_name );
+    if (use_logfile) {
+        eckit::LogTarget* logfile = new eckit::FileTarget(logfile_name);
 
-        if ( int( mpi::rank() ) == log_rank ) {
-            if ( Log::info() ) {
-                Log::info().addTarget( logfile );
+        if (int(mpi::rank()) == log_rank) {
+            if (Log::info()) {
+                Log::info().addTarget(logfile);
             }
-            if ( Log::warning() ) {
-                Log::warning().addTarget( logfile );
+            if (Log::warning()) {
+                Log::warning().addTarget(logfile);
             }
-            if ( Log::error() ) {
-                Log::error().addTarget( logfile );
+            if (Log::error()) {
+                Log::error().addTarget(logfile);
             }
-            debug_addTarget( logfile );
+            debug_addTarget(logfile);
         }
         else {
-            if ( Log::info() ) {
-                Log::info().setTarget( logfile );
+            if (Log::info()) {
+                Log::info().setTarget(logfile);
             }
-            if ( Log::warning() ) {
-                Log::warning().setTarget( logfile );
+            if (Log::warning()) {
+                Log::warning().setTarget(logfile);
             }
-            if ( Log::error() ) {
-                Log::error().setTarget( logfile );
+            if (Log::error()) {
+                Log::error().setTarget(logfile);
             }
-            debug_setTarget( logfile );
+            debug_setTarget(logfile);
         }
     }
     else {
-        if ( int( mpi::rank() ) != log_rank ) {
-            if ( Log::info() ) {
+        if (int(mpi::rank()) != log_rank) {
+            if (Log::info()) {
                 Log::info().reset();
             }
-            if ( Log::warning() ) {
+            if (Log::warning()) {
                 Log::warning().reset();
             }
-            if ( Log::error() ) {
+            if (Log::error()) {
                 Log::error().reset();
             }
             debug_reset();
